## v2.0.1 (2023-02-25)

### Fix

- finally have a new line added at the end of the help so that the prompt it correct

### Refactor

- refactor with black, isort, and ruff

## v2.0.0 (2023-01-27)

## v1.3.3 (2023-01-16)

### Fix

- should be NameError rather than Import Error

### Refactor

- misc refactor

## 1.3.2 (2022-09-28)

## 1.1.0 (2022-07-06)

### Feat

- feature complete and up-to-date with toolbox paradigm
- Parse docstrings with "docstring_parser".
- get type information from function annotations (#47)
- **subprograms**: add deeply nested subcommands (#35)
- **core**: add global options and arcomplete support (#32)
- **core**: add formatter_class RSTHelpFormatter (#29)
- **core**: add support for mando, ReST, Numpy, and Google docstrings

### Fix

- Fix setting of type and metavar.
- rst code blocks in readme
- **napoleon**: remove all Sphinx mentions
- **napoleon**: remove Sphinx dependencies
- **setuptools**: use find_packages instead of manually specifying them
- **core**: use getfullargspec when available
- **test**: remove sphinx from test requirements
- **terminal encoding**: messages can be displayed on ASCII terminals (#37)
- **travis**: upgrade pip
- **setup**: correctly make argparse a dependency for Python 2.6
- **core**: change SPHINX_RE so that it captures the entire indented text
- **travis-ci**: remove Python 3.2 from matrix and add Python 3.5
- **readme**: remove wip notice
- **travis-ci**: remove Python 3.2 from matrix and add Python 3.5
- **setup.py**: merged classifiers

## v0.3.2 (2014-08-07)

## v0.3.1 (2013-12-16)

## v0.3 (2013-12-10)
